@@ -75,6 +75,12 @@ impl From<Option<Border>> for Border {
     }
 }
 
+impl From<Radius> for Border {
+    fn from(source: Radius) -> Self {
+        Self::default().radius(source)
+    }
+}
+
 macro_rules! sides_style_shortcut_functions {
     ( $( $fn:ident() $(,)? )* ) => {
         $(
