@@ -1,14 +1,16 @@
 use crate::{unit::*, Style, StyleUpdater};
 
 /// ```
-/// use css_style::{Style, unit::{px, em}};
+/// use css_style::{Style, Gap, unit::{px, em}};
 ///
 /// Style::default()
 ///     .gap(px(2))
 ///     // this can take percent value too (.e.g 40%).
 ///     .gap(0.4)
 ///     // and can take row and column each with different value
-///     .gap((em(4.), em(8.)));
+///     .gap((em(4.), em(8.)))
+///     // we can also use declarative style like this:
+///     .gap(Gap::row(em(4.)).and_column(em(4.)));
 /// ```
 #[derive(Clone, Debug, PartialEq, Display)]
 pub enum Gap {
@@ -25,6 +27,20 @@ impl Gap {
     pub fn column(len: impl Into<LengthPercent>) -> Self {
         Gap::RowColumn(px(0).into(), len.into())
     }
+
+    pub fn and_row(self, len: impl Into<LengthPercent>) -> Self {
+        match self {
+            Gap::Value(val) => Gap::RowColumn(len.into(), val),
+            Gap::RowColumn(_, col) => Gap::RowColumn(len.into(), col),
+        }
+    }
+
+    pub fn and_column(self, len: impl Into<LengthPercent>) -> Self {
+        match self {
+            Gap::Value(val) => Gap::RowColumn(val, len.into()),
+            Gap::RowColumn(row, _) => Gap::RowColumn(row, len.into()),
+        }
+    }
 }
 
 impl<T> From<T> for Gap
