@@ -330,6 +330,22 @@ impl TextDecoration {
         self
     }
 
+    pub fn line_none(self) -> Self {
+        self.line(TextDecorationLine::None)
+    }
+
+    pub fn line_underline(self) -> Self {
+        self.line(TextDecorationLine::Underline)
+    }
+
+    pub fn line_overline(self) -> Self {
+        self.line(TextDecorationLine::Overline)
+    }
+
+    pub fn line_line_through(self) -> Self {
+        self.line(TextDecorationLine::LineThrough)
+    }
+
     pub fn color(mut self, value: impl Into<TextDecorationColor>) -> Self {
         match self {
             Self::Decoration { ref mut color, .. } => *color = Some(value.into()),
@@ -358,6 +374,14 @@ impl TextDecoration {
         self
     }
 
+    pub fn style_solid(self) -> Self {
+        self.style(TextDecorationStyle::Solid)
+    }
+
+    pub fn style_dashed(self) -> Self {
+        self.style(TextDecorationStyle::Dashed)
+    }
+
     // TODO: add shortcute functions none(), solid() ..etc
 }
 
